summaryrefslogtreecommitdiffstats
path: root/arts/builder
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:25 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:25 -0600
commitf59dfa08651a47f21d004e8e4cb5020b8035287e (patch)
tree0582273566661474af14fe8f1737cfe1e6527d46 /arts/builder
parent83fbc82a101309e171089f0d5ed080f82a367345 (diff)
downloadtdemultimedia-f59dfa08651a47f21d004e8e4cb5020b8035287e.tar.gz
tdemultimedia-f59dfa08651a47f21d004e8e4cb5020b8035287e.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 83fbc82a101309e171089f0d5ed080f82a367345.
Diffstat (limited to 'arts/builder')
-rw-r--r--arts/builder/createtool.cpp10
-rw-r--r--arts/builder/dirmanager.cpp2
-rw-r--r--arts/builder/execdlg.cpp58
-rw-r--r--arts/builder/execdlg.h4
-rw-r--r--arts/builder/interfacedlg.cpp60
-rw-r--r--arts/builder/main.cpp8
-rw-r--r--arts/builder/module.cpp2
-rw-r--r--arts/builder/portposdlg.cpp56
-rw-r--r--arts/builder/propertypanel.cpp10
-rw-r--r--arts/builder/propertypanel.h2
-rw-r--r--arts/builder/propertypanelbase.ui2
-rw-r--r--arts/builder/qttableview.cpp66
-rw-r--r--arts/builder/qttableview.h14
-rw-r--r--arts/builder/retrievedlg.cpp44
-rw-r--r--arts/builder/retrievedlg.h2
-rw-r--r--arts/builder/structureport.cpp2
16 files changed, 171 insertions, 171 deletions
diff --git a/arts/builder/createtool.cpp b/arts/builder/createtool.cpp
index ef26009f..f8d5c7e5 100644
--- a/arts/builder/createtool.cpp
+++ b/arts/builder/createtool.cpp
@@ -25,7 +25,7 @@
#include "structureport.h"
//#include <arts/debug.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <tqpainter.h>
#include <kmessagebox.h>
#include <klocale.h>
@@ -55,7 +55,7 @@ CreateTool::CreateTool(ModuleWidget *mwidget)
CreateTool::~CreateTool()
{
- mwidget->repaint(componentRect);
+ mwidget->tqrepaint(componentRect);
mwidget->setCursor(oldCursor);
mwidget->setMouseTracking(oldMouseTracking);
}
@@ -89,7 +89,7 @@ void CreateTool::mouseMoveEvent(TQMouseEvent *e)
&& mwidget->colXPos(x + width, &cellx2) && mwidget->rowYPos(y + height, &celly2);
if(!posok) return;
- mwidget->repaint(componentRect);
+ mwidget->tqrepaint(componentRect);
componentRect = TQRect(cellx, celly, cellx2 - cellx, celly2 - celly);
TQPainter *p = new TQPainter;
@@ -303,7 +303,7 @@ void ConnectPortsTool::mouseMoveEvent(TQMouseEvent *e)
{
TQPainter painter(mwidget);
painter.setPen(TQt::white);
- mwidget->repaint(TQRect(firstPos, lastPos).normalize());
+ mwidget->tqrepaint(TQRect(firstPos, lastPos).normalize());
painter.drawLine(firstPos, e->pos());
lastPos = e->pos();
}
@@ -334,6 +334,6 @@ void ConnectPortsTool::mouseReleaseEvent(TQMouseEvent *e)
}
}
}
- mwidget->repaint(TQRect(firstPos, lastPos).normalize());
+ mwidget->tqrepaint(TQRect(firstPos, lastPos).normalize());
mwidget->leaveTool(this);
}
diff --git a/arts/builder/dirmanager.cpp b/arts/builder/dirmanager.cpp
index 2f22f104..dae660b2 100644
--- a/arts/builder/dirmanager.cpp
+++ b/arts/builder/dirmanager.cpp
@@ -83,7 +83,7 @@ char *DirManager::directory(const char *subdir, const TQString &desc)
TQString dir = TQFile::decodeName(dirname);
message = i18n("You need the folder %1.\n"
"It will be used to store %2.\nShould I create it now?")
- .arg(dir).arg(desc);
+ .tqarg(dir).tqarg(desc);
if(KMessageBox::questionYesNo(0,message,i18n("aRts Folder Missing"),i18n("Create Folder"),i18n("Do Not Create"))
== KMessageBox::Yes)
diff --git a/arts/builder/execdlg.h b/arts/builder/execdlg.h
index 7c2c6d78..61348c0f 100644
--- a/arts/builder/execdlg.h
+++ b/arts/builder/execdlg.h
@@ -27,7 +27,7 @@
#include <tqtimer.h>
#include <tqlabel.h>
#include <tqscrollbar.h>
-#include <layout.h>
+#include <tqlayout.h>
class ExecDlg :public TQDialog {
Q_OBJECT
@@ -35,7 +35,7 @@ class ExecDlg :public TQDialog {
public:
TQTimer *cpuusagetimer;
TQLabel *cpuusagelabel;
- TQVBoxLayout *mainlayout,*sliderlayout;
+ TQVBoxLayout *maintqlayout,*slidertqlayout;
ExecutableStructure *structure;
void start();
diff --git a/arts/builder/interfacedlg.cpp b/arts/builder/interfacedlg.cpp
index 4d57c954..3b4d455a 100644
--- a/arts/builder/interfacedlg.cpp
+++ b/arts/builder/interfacedlg.cpp
@@ -21,7 +21,7 @@
#include "interfacedlg.h"
#include "structureport.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqlistbox.h>
#include <kbuttonbox.h>
@@ -45,46 +45,46 @@ InterfaceDlg::InterfaceDlg(TQWidget *parent) :TQDialog(parent,"Props", TRUE)
{
setCaption(i18n("aRts: Structureport View"));
- TQVBoxLayout *mainlayout = new TQVBoxLayout(this);
- //TQHBoxLayout *contentslayout = new TQHBoxLayout;
+ TQVBoxLayout *maintqlayout = new TQVBoxLayout(this);
+ //TQHBoxLayout *contentstqlayout = new TQHBoxLayout;
// object type
/*
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
TQLabel *objectlabel = new TQLabel(this);
TQFont labelfont(objectlabel->font());
labelfont.setPointSize(labelfont.pointSize()*3/2);
objectlabel->setFont(labelfont);
objectlabel->setText(TQString(" ")+i18n("Object type: ")+TQString(port->owner->name())+TQString(" "));
- objectlabel->setAlignment(AlignCenter);
+ objectlabel->tqsetAlignment(AlignCenter);
min_size(objectlabel);
- mainlayout->addWidget(objectlabel);
+ maintqlayout->addWidget(objectlabel);
*/
// port description
/*
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
TQLabel *portlabel = new TQLabel(this);
labelfont.setPointSize(labelfont.pointSize()*4/5);
portlabel->setFont(labelfont);
portlabel->setText(i18n("Port description: ")+ port->description);
min_size(portlabel);
- portlabel->setAlignment(AlignCenter);
- mainlayout->addWidget(portlabel);
+ portlabel->tqsetAlignment(AlignCenter);
+ maintqlayout->addWidget(portlabel);
- int labelwidth = imax(portlabel->sizeHint().width(),objectlabel->sizeHint().width());
+ int labelwidth = imax(portlabel->tqsizeHint().width(),objectlabel->tqsizeHint().width());
portlabel->setMinimumWidth(labelwidth);
objectlabel->setMinimumWidth(labelwidth);
// hruler
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator *ruler = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(ruler);
- mainlayout->addSpacing(5);
- mainlayout->addLayout(contentslayout);
+ maintqlayout->addWidget(ruler);
+ maintqlayout->addSpacing(5);
+ maintqlayout->addLayout(contentstqlayout);
*/
// list
@@ -93,23 +93,23 @@ InterfaceDlg::InterfaceDlg(TQWidget *parent) :TQDialog(parent,"Props", TRUE)
update();
listbox->setMinimumSize(340,400);
- mainlayout->addWidget(listbox);
+ maintqlayout->addWidget(listbox);
connect( listbox, TQT_SIGNAL( doubleClicked ( TQListBoxItem *)), this,
TQT_SLOT(accept()));
// hruler
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator *ruler2 = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(ruler2);
+ maintqlayout->addWidget(ruler2);
// buttons
- TQHBoxLayout *buttonlayout = new TQHBoxLayout;
- mainlayout->addSpacing(5);
- mainlayout->addLayout(buttonlayout);
- mainlayout->addSpacing(5);
+ TQHBoxLayout *buttontqlayout = new TQHBoxLayout;
+ maintqlayout->addSpacing(5);
+ maintqlayout->addLayout(buttontqlayout);
+ maintqlayout->addSpacing(5);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addSpacing(5);
KButtonBox *bbox = new KButtonBox(this);
bbox->addButton(KStdGuiItem::help(), TQT_TQOBJECT(this), TQT_SLOT( help() ));
@@ -121,14 +121,14 @@ InterfaceDlg::InterfaceDlg(TQWidget *parent) :TQDialog(parent,"Props", TRUE)
TQButton *cancelbutton = bbox->addButton(KStdGuiItem::cancel());
connect( cancelbutton, TQT_SIGNAL( clicked() ), TQT_SLOT(reject() ) );
- bbox->layout();
+ bbox->tqlayout();
//min_size(bbox);
- buttonlayout->addWidget(bbox);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addWidget(bbox);
+ buttontqlayout->addSpacing(5);
- //mainlayout->activate();
- mainlayout->freeze();
+ //maintqlayout->activate();
+ maintqlayout->freeze();
}
string InterfaceDlg::interfaceName()
@@ -159,10 +159,10 @@ void InterfaceDlg::update(const string& interface, const string& indent)
{
listbox->insertItem((indent + interface).c_str());
- vector<string> *children = Arts::Dispatcher::the()->interfaceRepo().queryChildren(interface);
- for (vector<string>::iterator ci = children->begin(); ci != children->end(); ++ci)
+ vector<string> *tqchildren = Arts::Dispatcher::the()->interfaceRepo().queryChildren(interface);
+ for (vector<string>::iterator ci = tqchildren->begin(); ci != tqchildren->end(); ++ci)
update(ci->c_str(), indent+" ");
- delete children;
+ delete tqchildren;
}
void InterfaceDlg::update()
diff --git a/arts/builder/main.cpp b/arts/builder/main.cpp
index 229f4f61..558f650c 100644
--- a/arts/builder/main.cpp
+++ b/arts/builder/main.cpp
@@ -441,7 +441,7 @@ void ArtsBuilderWindow::publish()
checkName();
structure->publish();
KMessageBox::information(this,
- i18n("The structure has been published as: '%1' on the server.").arg( structure->name().c_str() ));
+ i18n("The structure has been published as: '%1' on the server.").tqarg( structure->name().c_str() ));
}
TQString ArtsBuilderWindow::getOpenFilename(const char *pattern, const char *initialDir)
@@ -587,7 +587,7 @@ bool ArtsBuilderWindow::save(TQString filename)
if(file.status()) {
KMessageBox::sorry(this,
i18n("The file '%1' could not be opened for writing: %2")
- .arg(filename).arg(strerror(file.status())),
+ .tqarg(filename).tqarg(strerror(file.status())),
i18n("aRts Warning"));
return false;
}
@@ -597,7 +597,7 @@ bool ArtsBuilderWindow::save(TQString filename)
if(!file.close()) {
KMessageBox::sorry(this,
i18n("Saving to file '%1' could not be finished correctly: %2")
- .arg(filename).arg(strerror(file.status())),
+ .tqarg(filename).tqarg(strerror(file.status())),
i18n("aRts Warning"));
return false;
}
@@ -872,7 +872,7 @@ ArtsBuilderApp::ArtsBuilderApp(TQString filename)
mainWindow->open(filename);
} else {
KMessageBox::sorry(0,
- i18n("The specified file '%1' does not exist.").arg(filename),
+ i18n("The specified file '%1' does not exist.").tqarg(filename),
i18n("aRts Warning"));
}
}
diff --git a/arts/builder/module.cpp b/arts/builder/module.cpp
index 2d452dc5..099f01e7 100644
--- a/arts/builder/module.cpp
+++ b/arts/builder/module.cpp
@@ -24,7 +24,7 @@
#include <stdio.h>
#include <arts/debug.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <tqdrawutil.h>
#include <kiconloader.h>
#include <algorithm>
diff --git a/arts/builder/portposdlg.cpp b/arts/builder/portposdlg.cpp
index e165cc17..63f2546c 100644
--- a/arts/builder/portposdlg.cpp
+++ b/arts/builder/portposdlg.cpp
@@ -21,7 +21,7 @@
#include "portposdlg.h"
#include "structureport.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqlistbox.h>
#include <kbuttonbox.h>
@@ -46,46 +46,46 @@ PortPosDlg::PortPosDlg(TQWidget *parent, Structure *structure) :TQDialog(parent,
setCaption(i18n("aRts: Structureport View"));
- TQVBoxLayout *mainlayout = new TQVBoxLayout(this);
- //TQHBoxLayout *contentslayout = new TQHBoxLayout;
+ TQVBoxLayout *maintqlayout = new TQVBoxLayout(this);
+ //TQHBoxLayout *contentstqlayout = new TQHBoxLayout;
// object type
/*
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
TQLabel *objectlabel = new TQLabel(this);
TQFont labelfont(objectlabel->font());
labelfont.setPointSize(labelfont.pointSize()*3/2);
objectlabel->setFont(labelfont);
objectlabel->setText(TQString(" ")+i18n("Object type: ")+TQString(port->owner->name())+TQString(" "));
- objectlabel->setAlignment(AlignCenter);
+ objectlabel->tqsetAlignment(AlignCenter);
min_size(objectlabel);
- mainlayout->addWidget(objectlabel);
+ maintqlayout->addWidget(objectlabel);
*/
// port description
/*
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
TQLabel *portlabel = new TQLabel(this);
labelfont.setPointSize(labelfont.pointSize()*4/5);
portlabel->setFont(labelfont);
portlabel->setText(i18n("Port description: ")+ port->description);
min_size(portlabel);
- portlabel->setAlignment(AlignCenter);
- mainlayout->addWidget(portlabel);
+ portlabel->tqsetAlignment(AlignCenter);
+ maintqlayout->addWidget(portlabel);
- int labelwidth = imax(portlabel->sizeHint().width(),objectlabel->sizeHint().width());
+ int labelwidth = imax(portlabel->tqsizeHint().width(),objectlabel->tqsizeHint().width());
portlabel->setMinimumWidth(labelwidth);
objectlabel->setMinimumWidth(labelwidth);
// hruler
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator *ruler = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(ruler);
- mainlayout->addSpacing(5);
- mainlayout->addLayout(contentslayout);
+ maintqlayout->addWidget(ruler);
+ maintqlayout->addSpacing(5);
+ maintqlayout->addLayout(contentstqlayout);
*/
// list
@@ -94,21 +94,21 @@ PortPosDlg::PortPosDlg(TQWidget *parent, Structure *structure) :TQDialog(parent,
update();
listbox->setMinimumSize(100,200);
- mainlayout->addWidget(listbox);
+ maintqlayout->addWidget(listbox);
// hruler
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator *ruler2 = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(ruler2);
+ maintqlayout->addWidget(ruler2);
// buttons
- TQHBoxLayout *buttonlayout = new TQHBoxLayout;
- mainlayout->addSpacing(5);
- mainlayout->addLayout(buttonlayout);
- mainlayout->addSpacing(5);
+ TQHBoxLayout *buttontqlayout = new TQHBoxLayout;
+ maintqlayout->addSpacing(5);
+ maintqlayout->addLayout(buttontqlayout);
+ maintqlayout->addSpacing(5);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addSpacing(5);
KButtonBox *bbox = new KButtonBox(this);
bbox->addButton(KStdGuiItem::help(), TQT_TQOBJECT(this), TQT_SLOT( help() ));
@@ -133,14 +133,14 @@ PortPosDlg::PortPosDlg(TQWidget *parent, Structure *structure) :TQDialog(parent,
TQButton *cancelbutton = bbox->addButton(i18n("Cancel"));
connect( cancelbutton, TQT_SIGNAL( clicked() ), TQT_SLOT(reject() ) );
*/
- bbox->layout();
+ bbox->tqlayout();
//min_size(bbox);
- buttonlayout->addWidget(bbox);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addWidget(bbox);
+ buttontqlayout->addSpacing(5);
- //mainlayout->activate();
- mainlayout->freeze();
+ //maintqlayout->activate();
+ maintqlayout->freeze();
}
void PortPosDlg::raise()
@@ -247,7 +247,7 @@ void PortPosDlg::update()
}
}
}
- listbox->repaint();
+ listbox->tqrepaint();
}
void PortPosDlg::help()
diff --git a/arts/builder/propertypanel.cpp b/arts/builder/propertypanel.cpp
index 65dcd49b..df76588a 100644
--- a/arts/builder/propertypanel.cpp
+++ b/arts/builder/propertypanel.cpp
@@ -26,7 +26,7 @@
#include <kdebug.h>
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqpushbutton.h>
#include <tqbuttongroup.h>
#include <tqradiobutton.h>
@@ -115,7 +115,7 @@ void PropertyPanel::setSelectedComponent( StructureComponent *component )
if(component->pixmap())
{
moduleIconLabel->setPixmap( *component->pixmap() );
- moduleIconLabel->setMinimumSize( moduleIconLabel->sizeHint() );
+ moduleIconLabel->setMinimumSize( moduleIconLabel->tqsizeHint() );
moduleIconLabel->show();
}
else
@@ -128,11 +128,11 @@ void PropertyPanel::setSelectedComponent( StructureComponent *component )
it != modulePorts.end(); it++)
{
TQString portTitle = (*it)->description
- + TQString(" (%1)").arg( (*it)->PortDesc.type().direction == Arts::output ?
+ + TQString(" (%1)").tqarg( (*it)->PortDesc.type().direction == Arts::output ?
i18n("OUTPUT") : i18n("INPUT") );
portCombo->insertItem( portTitle );
}
- //portCombo->setMinimumSize( portCombo->sizeHint() );
+ //portCombo->setMinimumSize( portCombo->tqsizeHint() );
setEnabled(true);
}
}
@@ -344,7 +344,7 @@ bool PropertyPanel::eventFilter( TQObject *o, TQEvent *e )
TQString entered = TQT_TQKEYEVENT(e)->text();
bool goodString = entered.length() > 0;
-// kdDebug() << TQString("pressed '%1'").arg(entered) << endl;
+// kdDebug() << TQString("pressed '%1'").tqarg(entered) << endl;
for( unsigned int i = 0; i < entered.length(); i++)
goodString = goodString && entered[i].isLetterOrNumber();
diff --git a/arts/builder/propertypanel.h b/arts/builder/propertypanel.h
index cfe417f2..cf34fe65 100644
--- a/arts/builder/propertypanel.h
+++ b/arts/builder/propertypanel.h
@@ -21,7 +21,7 @@
#define PROPERTYPANEL_H
#include "propertypanelbase.h"
-#include "palette.h"
+#include "tqpalette.h"
#include <vector>
#include <list>
diff --git a/arts/builder/propertypanelbase.ui b/arts/builder/propertypanelbase.ui
index 0ff20382..b327b33f 100644
--- a/arts/builder/propertypanelbase.ui
+++ b/arts/builder/propertypanelbase.ui
@@ -314,7 +314,7 @@
<property name="name">
<cstring>tipLabel</cstring>
</property>
- <property name="alignment">
+ <property name="tqalignment">
<set>WordBreak|AlignVCenter|AlignLeft</set>
</property>
<property name="wordwrap" stdset="0">
diff --git a/arts/builder/qttableview.h b/arts/builder/qttableview.h
index 3160a38a..7d4f14e2 100644
--- a/arts/builder/qttableview.h
+++ b/arts/builder/qttableview.h
@@ -32,9 +32,9 @@ public:
virtual void setPalette( const TQPalette & );
void show();
- void repaint( bool erase=TRUE );
- void repaint( int x, int y, int w, int h, bool erase=TRUE );
- void repaint( const TQRect &, bool erase=TRUE );
+ void tqrepaint( bool erase=TRUE );
+ void tqrepaint( int x, int y, int w, int h, bool erase=TRUE );
+ void tqrepaint( const TQRect &, bool erase=TRUE );
protected:
QtTableView( TQWidget *parent=0, const char *name=0, WFlags f=0 );
@@ -235,11 +235,11 @@ inline TQRect QtTableView::cellUpdateRect() const
inline bool QtTableView::autoUpdate() const
{ return isUpdatesEnabled(); }
-inline void QtTableView::repaint( bool erase )
-{ repaint( 0, 0, width(), height(), erase ); }
+inline void QtTableView::tqrepaint( bool erase )
+{ tqrepaint( 0, 0, width(), height(), erase ); }
-inline void QtTableView::repaint( const TQRect &r, bool erase )
-{ repaint( r.x(), r.y(), r.width(), r.height(), erase ); }
+inline void QtTableView::tqrepaint( const TQRect &r, bool erase )
+{ tqrepaint( r.x(), r.y(), r.width(), r.height(), erase ); }
inline void QtTableView::updateScrollBars()
{ updateScrollBars( 0 ); }
diff --git a/arts/builder/retrievedlg.cpp b/arts/builder/retrievedlg.cpp
index 94dca3d4..5b738471 100644
--- a/arts/builder/retrievedlg.cpp
+++ b/arts/builder/retrievedlg.cpp
@@ -20,7 +20,7 @@
*/
#include "retrievedlg.h"
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqlistbox.h>
#include <kbuttonbox.h>
@@ -37,33 +37,33 @@
#include <tqpushbutton.h>
static void min_size(TQWidget *w) {
- w->setMinimumSize(w->sizeHint());
+ w->setMinimumSize(w->tqsizeHint());
}
RetrieveDlg::RetrieveDlg(TQWidget *parent) :TQDialog(parent,"X", TRUE)
{
setCaption(i18n("Retrieve Structure From Server"));
- TQVBoxLayout *mainlayout = new TQVBoxLayout(this);
+ TQVBoxLayout *maintqlayout = new TQVBoxLayout(this);
// caption label: "Synthesis running..."
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
TQLabel *captionlabel = new TQLabel(this);
TQFont labelfont(captionlabel->font());
labelfont.setPointSize(labelfont.pointSize()*3/2);
captionlabel->setFont(labelfont);
captionlabel->setText(TQString(" ")+i18n("Published structures")+TQString(" "));
- captionlabel->setAlignment(AlignCenter);
+ captionlabel->tqsetAlignment(AlignCenter);
min_size(captionlabel);
- mainlayout->addWidget(captionlabel);
+ maintqlayout->addWidget(captionlabel);
// hruler
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator *ruler2 = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(ruler2);
- mainlayout->addSpacing(5);
+ maintqlayout->addWidget(ruler2);
+ maintqlayout->addSpacing(5);
// listwidget
@@ -85,23 +85,23 @@ RetrieveDlg::RetrieveDlg(TQWidget *parent) :TQDialog(parent,"X", TRUE)
listbox->insertItem((*ni).c_str());
#endif
- mainlayout->addWidget(listbox);
+ maintqlayout->addWidget(listbox);
// hruler
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator *ruler = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(ruler);
- mainlayout->addSpacing(5);
+ maintqlayout->addWidget(ruler);
+ maintqlayout->addSpacing(5);
// buttons
- TQHBoxLayout *buttonlayout = new TQHBoxLayout;
- mainlayout->addSpacing(5);
- mainlayout->addLayout(buttonlayout);
- mainlayout->addSpacing(5);
+ TQHBoxLayout *buttontqlayout = new TQHBoxLayout;
+ maintqlayout->addSpacing(5);
+ maintqlayout->addLayout(buttontqlayout);
+ maintqlayout->addSpacing(5);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addSpacing(5);
KButtonBox *bbox = new KButtonBox(this);
bbox->addButton(KStdGuiItem::help(), TQT_TQOBJECT(this), TQT_SLOT( help() ));
@@ -113,12 +113,12 @@ RetrieveDlg::RetrieveDlg(TQWidget *parent) :TQDialog(parent,"X", TRUE)
TQButton *okbutton = bbox->addButton(KStdGuiItem::ok());
connect( okbutton, TQT_SIGNAL( clicked() ), TQT_SLOT(accept() ) );
- bbox->layout();
+ bbox->tqlayout();
- buttonlayout->addWidget(bbox);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addWidget(bbox);
+ buttontqlayout->addSpacing(5);
- mainlayout->freeze();
+ maintqlayout->freeze();
}
TQString RetrieveDlg::result()
diff --git a/arts/builder/retrievedlg.h b/arts/builder/retrievedlg.h
index dfc079e1..51649c4f 100644
--- a/arts/builder/retrievedlg.h
+++ b/arts/builder/retrievedlg.h
@@ -29,7 +29,7 @@
#include <tqlabel.h>
#include <tqscrollbar.h>
#include <tqlineedit.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlistbox.h>
#include <string>
diff --git a/arts/builder/structureport.cpp b/arts/builder/structureport.cpp
index b8d59d1e..e61fa2a9 100644
--- a/arts/builder/structureport.cpp
+++ b/arts/builder/structureport.cpp
@@ -22,7 +22,7 @@
#include "structureport.h"
#include "drawutils.h"
#include <tqpainter.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <tqdrawutil.h>
#include <tqbitmap.h>
#include <assert.h>
diff --git a/arts/builder/execdlg.cpp b/arts/builder/execdlg.cpp
index 8ead524a..790691e8 100644
--- a/arts/builder/execdlg.cpp
+++ b/arts/builder/execdlg.cpp
@@ -20,7 +20,7 @@
*/
#include <tqfile.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqbuttongroup.h>
#include <tqradiobutton.h>
@@ -41,7 +41,7 @@
#ifndef KDE_USE_FINAL
static void min_size(TQWidget *w) {
- w->setMinimumSize(w->sizeHint());
+ w->setMinimumSize(w->tqsizeHint());
}
#endif
@@ -53,19 +53,19 @@ ExecDlg::ExecDlg(TQWidget *parent, ExecutableStructure *structure)
setCaption(i18n("aRts Module Execution"));
- mainlayout = new TQVBoxLayout(this);
+ maintqlayout = new TQVBoxLayout(this);
// caption label: "Synthesis running..."
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
TQLabel *captionlabel = new TQLabel(this);
TQFont labelfont(captionlabel->font());
labelfont.setPointSize(labelfont.pointSize()*3/2);
captionlabel->setFont(labelfont);
captionlabel->setText(TQString(" ")+i18n("Synthesis running...")+TQString(" "));
- captionlabel->setAlignment(AlignCenter);
+ captionlabel->tqsetAlignment(AlignCenter);
min_size(captionlabel);
- mainlayout->addWidget(captionlabel);
+ maintqlayout->addWidget(captionlabel);
cpuusagelabel = new TQLabel(this);
cpuusagelabel->setText(i18n("CPU usage: unknown"));
@@ -78,41 +78,41 @@ ExecDlg::ExecDlg(TQWidget *parent, ExecutableStructure *structure)
cpuusagetimer->start( 2000, false );
min_size(cpuusagelabel);
- mainlayout->addWidget(cpuusagelabel);
+ maintqlayout->addWidget(cpuusagelabel);
-// ruler above the sliderlayout
+// ruler above the slidertqlayout
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
KSeparator* sep = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(sep);
- mainlayout->addSpacing(5);
+ maintqlayout->addWidget(sep);
+ maintqlayout->addSpacing(5);
// sliders, controlpanels
- sliderlayout = new TQVBoxLayout;
- mainlayout->addLayout(sliderlayout);
+ slidertqlayout = new TQVBoxLayout;
+ maintqlayout->addLayout(slidertqlayout);
#if 0 /* PORT */
this->GUIServer = GUIServer;
GUIServer->setGlobalParent(this);
- GUIServer->setGlobalLayout(sliderlayout);
+ GUIServer->setGlobalLayout(slidertqlayout);
#endif
-// hruler below the sliderlayout
+// hruler below the slidertqlayout
- mainlayout->addSpacing(5);
+ maintqlayout->addSpacing(5);
sep = new KSeparator( KSeparator::HLine, this);
- mainlayout->addWidget(sep);
- mainlayout->addSpacing(5);
+ maintqlayout->addWidget(sep);
+ maintqlayout->addSpacing(5);
// buttons
- TQHBoxLayout *buttonlayout = new TQHBoxLayout;
- mainlayout->addSpacing(5);
- mainlayout->addLayout(buttonlayout);
- mainlayout->addSpacing(5);
+ TQHBoxLayout *buttontqlayout = new TQHBoxLayout;
+ maintqlayout->addSpacing(5);
+ maintqlayout->addLayout(buttontqlayout);
+ maintqlayout->addSpacing(5);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addSpacing(5);
KButtonBox *bbox = new KButtonBox(this);
bbox->addButton(KStdGuiItem::help(), TQT_TQOBJECT(this), TQT_SLOT( help() ));
@@ -125,18 +125,18 @@ ExecDlg::ExecDlg(TQWidget *parent, ExecutableStructure *structure)
TQButton *okbutton = bbox->addButton(KStdGuiItem::ok());
connect( okbutton, TQT_SIGNAL( clicked() ), TQT_SLOT(accept() ) );
- bbox->layout();
+ bbox->tqlayout();
//min_size(bbox);
- buttonlayout->addWidget(bbox);
- buttonlayout->addSpacing(5);
+ buttontqlayout->addWidget(bbox);
+ buttontqlayout->addSpacing(5);
-// mainlayout->freeze();
+// maintqlayout->freeze();
}
void ExecDlg::start()
{
- mainlayout->freeze();
+ maintqlayout->freeze();
}
void ExecDlg::guiServerTick()
@@ -151,7 +151,7 @@ void ExecDlg::updateCpuUsage()
#if 0 /* TODO:PORT */
char cpuusage[100];
- ArtsCorba::Status s = Synthesizer->getStatus();
+ ArtsCorba::tqStatus s = Synthesizer->gettqStatus();
if(s.halted)
{
cpuusagetimer->stop();
diff --git a/arts/builder/qttableview.cpp b/arts/builder/qttableview.cpp
index 4db8af17..f8716b44 100644
--- a/arts/builder/qttableview.cpp
+++ b/arts/builder/qttableview.cpp
@@ -34,8 +34,8 @@ enum ScrollBarDirtyFlags {
};
-#define HSBEXT horizontalScrollBar()->sizeHint().height()
-#define VSBEXT verticalScrollBar()->sizeHint().width()
+#define HSBEXT horizontalScrollBar()->tqsizeHint().height()
+#define VSBEXT verticalScrollBar()->tqsizeHint().width()
class TQCornerSquare : public TQWidget // internal class
@@ -88,7 +88,7 @@ void TQCornerSquare::paintEvent( TQPaintEvent * )
used by functions such as setXOffset() or maxYOffset().
\i The \e widget coordinates. (0,0) is the top-left corner of the widget,
- \e including the frame. They are used by functions such as repaint().
+ \e including the frame. They are used by functions such as tqrepaint().
\i The \e view coordinates. (0,0) is the top-left corner of the view, \e
excluding the frame. This is the least-used coordinate system; it is used by
@@ -135,7 +135,7 @@ void TQCornerSquare::paintEvent( TQPaintEvent * )
The \link setCellHeight() cell height\endlink and \link setCellWidth()
cell width\endlink are set to 0.
- Frame line shapes (TQFrame::HLink and TQFrame::VLine) are disallowed;
+ Frame line tqshapes (TQFrame::HLink and TQFrame::VLine) are disallowed;
see TQFrame::setFrameStyle().
Note that the \a f argument is \e not \link setTableFlags() table
@@ -207,7 +207,7 @@ void QtTableView::show()
/*!
- \overload void QtTableView::repaint( bool erase )
+ \overload void QtTableView::tqrepaint( bool erase )
Repaints the entire view.
*/
@@ -221,16 +221,16 @@ void QtTableView::show()
If \a w is negative, it is replaced with <code>width() - x</code>.
If \a h is negative, it is replaced with <code>height() - y</code>.
- Doing a repaint() usually is faster than doing an update(), but
+ Doing a tqrepaint() usually is faster than doing an update(), but
calling update() many times in a row will generate a single paint
event.
At present, QtTableView is the only widget that reimplements \link
- TQWidget::repaint() repaint()\endlink. It does this because by
+ TQWidget::tqrepaint() tqrepaint()\endlink. It does this because by
clearing and then repainting one cell at at time, it can make the
screen flicker less than it would otherwise. */
-void QtTableView::repaint( int x, int y, int w, int h, bool erase )
+void QtTableView::tqrepaint( int x, int y, int w, int h, bool erase )
{
if ( !isVisible() || testWState(WState_BlockUpdates) )
return;
@@ -249,7 +249,7 @@ void QtTableView::repaint( int x, int y, int w, int h, bool erase )
}
/*!
- \overload void QtTableView::repaint( const TQRect &r, bool erase )
+ \overload void QtTableView::tqrepaint( const TQRect &r, bool erase )
Replaints rectangle \a r. If \a erase is TRUE draws the background
using the palette's background.
*/
@@ -288,7 +288,7 @@ void QtTableView::setNumRows( int rows )
nRows = rows;
if ( autoUpdate() && isVisible() &&
( oldLastVisible != lastRowVisible() || oldTopCell != topCell() ) )
- repaint( oldTopCell != topCell() );
+ tqrepaint( oldTopCell != topCell() );
} else {
// Be more careful - if destructing, bad things might happen.
nRows = rows;
@@ -328,7 +328,7 @@ void QtTableView::setNumCols( int cols )
if ( autoUpdate() && isVisible() ) {
int maxCol = lastColVisible();
if ( maxCol >= oldCols || maxCol >= nCols )
- repaint();
+ tqrepaint();
}
updateScrollBars( horRange );
updateFrameSize();
@@ -591,7 +591,7 @@ void QtTableView::setCellWidth( int cellWidth )
updateScrollBars( horSteps | horRange );
if ( autoUpdate() && isVisible() )
- repaint();
+ tqrepaint();
}
@@ -643,7 +643,7 @@ void QtTableView::setCellHeight( int cellHeight )
#endif
cellH = (short)cellHeight;
if ( autoUpdate() && isVisible() )
- repaint();
+ tqrepaint();
updateScrollBars( verSteps | verRange );
}
@@ -817,7 +817,7 @@ void QtTableView::setTableFlags( uint f )
(f & Tbl_snapToVGrid) != 0 && yCellDelta != 0 ) {
snapToGrid( (f & Tbl_snapToHGrid) != 0, // do snapping
(f & Tbl_snapToVGrid) != 0 );
- repaintMask |= Tbl_snapToGrid; // repaint table
+ repaintMask |= Tbl_snapToGrid; // tqrepaint table
}
}
@@ -825,7 +825,7 @@ void QtTableView::setTableFlags( uint f )
setAutoUpdate( TRUE );
updateScrollBars();
if ( isVisible() && (f & repaintMask) )
- repaint();
+ tqrepaint();
}
}
@@ -881,7 +881,7 @@ void QtTableView::clearTableFlags( uint f )
(f & Tbl_smoothVScrolling) != 0 && yCellDelta != 0 ) {
snapToGrid( (f & Tbl_smoothHScrolling) != 0, // do snapping
(f & Tbl_smoothVScrolling) != 0 );
- repaintMask |= Tbl_smoothScrolling; // repaint table
+ repaintMask |= Tbl_smoothScrolling; // tqrepaint table
}
}
if ( f & Tbl_snapToHGrid ) {
@@ -894,7 +894,7 @@ void QtTableView::clearTableFlags( uint f )
setAutoUpdate( TRUE );
updateScrollBars(); // returns immediately if nothing to do
if ( isVisible() && (f & repaintMask) )
- repaint();
+ tqrepaint();
}
}
@@ -916,20 +916,20 @@ void QtTableView::clearTableFlags( uint f )
automatically whenever it has changed in some way (for example, when a
\link setTableFlags() flag\endlink is changed).
- If \a enable is FALSE, the view does NOT repaint itself or update
+ If \a enable is FALSE, the view does NOT tqrepaint itself or update
its internal state variables when it is changed. This can be
useful to avoid flicker during large changes and is singularly
useless otherwise. Disable auto-update, do the changes, re-enable
- auto-update and call repaint().
+ auto-update and call tqrepaint().
\warning Do not leave the view in this state for a long time
(i.e., between events). If, for example, the user interacts with the
view when auto-update is off, strange things can happen.
- Setting auto-update to TRUE does not repaint the view; you must call
- repaint() to do this.
+ Setting auto-update to TRUE does not tqrepaint the view; you must call
+ tqrepaint() to do this.
- \sa autoUpdate(), repaint()
+ \sa autoUpdate(), tqrepaint()
*/
void QtTableView::setAutoUpdate( bool enable )
@@ -963,7 +963,7 @@ void QtTableView::updateCell( int row, int col, bool erase )
TQRect uR = TQRect( xPos, yPos,
cellW ? cellW : cellWidth(col),
cellH ? cellH : cellHeight(row) );
- repaint( uR.intersect(viewRect()), erase );
+ tqrepaint( uR.intersect(viewRect()), erase );
}
@@ -1379,13 +1379,13 @@ void QtTableView::paintEvent( TQPaintEvent *e )
// Note that this needs to be done regardless whether we do
// eraseInPaint or not. Reason: a subclass may implement
// flicker-freeness and encourage the use of repaint(FALSE).
// The subclass, however, cannot draw all pixels, just those
// inside the cells. So QtTableView is reponsible for all pixels
// outside the cells.
TQRect viewR = viewRect();
- const TQColorGroup g = colorGroup();
+ const TQColorGroup g = tqcolorGroup();
if ( xPos <= maxX ) {
TQRect r = viewR;
@@ -1426,7 +1426,7 @@ void QtTableView::resizeEvent( TQResizeEvent * )
void QtTableView::updateView()
{
- repaint( viewRect() );
+ tqrepaint( viewRect() );
}
/*!
@@ -1443,7 +1443,7 @@ TQScrollBar *QtTableView::verticalScrollBar() const
#ifndef TQT_NO_CURSOR
sb->setCursor( arrowCursor );
#endif
- sb->resize( sb->sizeHint() ); // height is irrelevant
+ sb->resize( sb->tqsizeHint() ); // height is irrelevant
Q_CHECK_PTR(sb);
sb->setTracking( FALSE );
sb->setFocusPolicy( TQ_NoFocus );
@@ -1474,7 +1474,7 @@ TQScrollBar *QtTableView::horizontalScrollBar() const
#ifndef TQT_NO_CURSOR
sb->setCursor( arrowCursor );
#endif
- sb->resize( sb->sizeHint() ); // width is irrelevant
+ sb->resize( sb->tqsizeHint() ); // width is irrelevant
sb->setFocusPolicy( TQ_NoFocus );
Q_CHECK_PTR(sb);
sb->setTracking( FALSE );
@@ -1522,7 +1522,7 @@ void QtTableView::setHorScrollBar( bool on, bool update )
else
sbDirty = sbDirty | verMask;
if ( hideScrollBar && isVisible() )
- repaint( hScrollBar->x(), hScrollBar->y(),
+ tqrepaint( hScrollBar->x(), hScrollBar->y(),
width() - hScrollBar->x(), hScrollBar->height() );
}
if ( update )
@@ -1561,7 +1561,7 @@ void QtTableView::setVerScrollBar( bool on, bool update )
else
sbDirty = sbDirty | horMask;
if ( hideScrollBar && isVisible() )
- repaint( vScrollBar->x(), vScrollBar->y(),
+ tqrepaint( vScrollBar->x(), vScrollBar->y(),
vScrollBar->width(), height() - vScrollBar->y() );
}
if ( update )
@@ -2006,7 +2006,7 @@ void QtTableView::updateScrollBars( uint f )
if ( sbDirty & horValue )
hScrollBar->setValue( xOffs );
- // show scrollbar only when it has a sane geometry
+ // show scrollbar only when it has a sane tqgeometry
if ( !hScrollBar->isVisible() )
hScrollBar->show();
}
@@ -2030,7 +2030,7 @@ void QtTableView::updateScrollBars( uint f )
if ( sbDirty & verValue )
vScrollBar->setValue( yOffs );
- // show scrollbar only when it has a sane geometry
+ // show scrollbar only when it has a sane tqgeometry
if ( !vScrollBar->isVisible() )
vScrollBar->show();
}
@@ -2253,7 +2253,7 @@ void QtTableView::showOrHideScrollBars()
Call this function when the table view's total size is changed;
typically because the result of cellHeight() or cellWidth() have changed.
- This function does not repaint the widget.
+ This function does not tqrepaint the widget.
*/
void QtTableView::updateTableSize()
@@ -1379,13 +1379,13 @@ void QtTableView::paintEvent( TQPaintEvent *e )
// Note that this needs to be done regardless whether we do
// eraseInPaint or not. Reason: a subclass may implement
- // flicker-freeness and encourage the use of repaint(FALSE).
+ // flicker-freeness and encourage the use of tqrepaint(FALSE).
// The subclass, however, cannot draw all pixels, just those
// inside the cells. So QtTableView is reponsible for all pixels